@@ -1,4 +1,4 @@
-/* $Id: glibmm.h 417 2007-06-12 13:38:39Z murrayc $ */
+/* $Id: glibmm.h 667 2008-06-13 15:51:43Z murrayc $ */
 
 /* glibmm - a C++ wrapper for the GLib toolkit
  *
@@ -25,6 +25,7 @@
 #include <glibmmconfig.h>
 //#include <glibmm/i18n.h> //This must be included by the application, after system headers such as <iostream>.
 #include <glibmm/arrayhandle.h>
+#include <glibmm/checksum.h>
 #include <glibmm/class.h>
 #include <glibmm/containerhandle_shared.h>
 #include <glibmm/convert.h>
@@ -66,6 +67,7 @@
 #include <glibmm/threadpool.h>
 #include <glibmm/timer.h>
 #include <glibmm/timeval.h>
+#include <glibmm/tree.h>
 #include <glibmm/uriutils.h>
 #include <glibmm/ustring.h>
 #include <glibmm/value.h>
